### Koza

Data ingest framework for the Biolink model

*Disclaimer*: Koza is in pre-alpha

Author declarative transforms with dataclasses and less boilerplate


#### Installation

```
pip install koza
```

#### Getting Started

Hello world

#### A Small Example


TODO example using string

